# __main__.py
from cochar import Character

def main():
    return Character

if __name__ == "__main__":
    print(main())